==> chaosmesh-model-5.2.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/KernelChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface KernelChaosStatusFluent<A extends KernelChaosStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildExperiment instead.
 * @return The buildable object.
 */
@Deprecated public ExperimentStatus getExperiment();
    public ExperimentStatus buildExperiment();
    public A withExperiment(ExperimentStatus experiment);
    public Boolean hasExperiment();
    public KernelChaosStatusFluent.ExperimentNested<A> withNewExperiment();
    public KernelChaosStatusFluent.ExperimentNested<A> withNewExperimentLike(ExperimentStatus item);
    public KernelChaosStatusFluent.ExperimentNested<A> editExperiment();
    public KernelChaosStatusFluent.ExperimentNested<A> editOrNewExperiment();
    public KernelChaosStatusFluent.ExperimentNested<A> editOrNewExperimentLike(ExperimentStatus item);
    public String getFailedMessage();
    public A withFailedMessage(String failedMessage);
    public Boolean hasFailedMessage();
    public A withNewFailedMessage(String arg1);
    public A withNewFailedMessage(StringBuilder arg1);
    public A withNewFailedMessage(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildScheduler instead.
 * @return The buildable object.
 */
@Deprecated public ScheduleStatus getScheduler();
    public ScheduleStatus buildScheduler();
    public A withScheduler(ScheduleStatus scheduler);
    public Boolean hasScheduler();
    public A withNewScheduler(String nextRecover,String nextStart);
    public KernelChaosStatusFluent.SchedulerNested<A> withNewScheduler();
    public KernelChaosStatusFluent.SchedulerNested<A> withNewSchedulerLike(ScheduleStatus item);
    public KernelChaosStatusFluent.SchedulerNested<A> editScheduler();
    public KernelChaosStatusFluent.SchedulerNested<A> editOrNewScheduler();
    public KernelChaosStatusFluent.SchedulerNested<A> editOrNewSchedulerLike(ScheduleStatus item);
    public interface ExperimentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExperimentStatusFluent<KernelChaosStatusFluent.ExperimentNested<N>> {

            public N and();
            public N endExperiment();    }


    public interface SchedulerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ScheduleStatusFluent<KernelChaosStatusFluent.SchedulerNested<N>> {

            public N and();
            public N endScheduler();    }


}

==> chaosmesh-model-5.3.0-sources.jar: annotations/io/fabric8/chaosmesh/v1alpha1/KernelChaosStatusFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface KernelChaosStatusFluent<A extends KernelChaosStatusFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildExperiment instead.
 * @return The buildable object.
 */
@Deprecated public ExperimentStatus getExperiment();
    public ExperimentStatus buildExperiment();
    public A withExperiment(ExperimentStatus experiment);
    public Boolean hasExperiment();
    public KernelChaosStatusFluent.ExperimentNested<A> withNewExperiment();
    public KernelChaosStatusFluent.ExperimentNested<A> withNewExperimentLike(ExperimentStatus item);
    public KernelChaosStatusFluent.ExperimentNested<A> editExperiment();
    public KernelChaosStatusFluent.ExperimentNested<A> editOrNewExperiment();
    public KernelChaosStatusFluent.ExperimentNested<A> editOrNewExperimentLike(ExperimentStatus item);
    public String getFailedMessage();
    public A withFailedMessage(String failedMessage);
    public Boolean hasFailedMessage();
    public A withNewFailedMessage(StringBuilder arg1);
    public A withNewFailedMessage(int[] arg1,int arg2,int arg3);
    public A withNewFailedMessage(char[] arg1);
    public A withNewFailedMessage(StringBuffer arg1);
    public A withNewFailedMessage(byte[] arg1,int arg2);
    public A withNewFailedMessage(byte[] arg1);
    public A withNewFailedMessage(char[] arg1,int arg2,int arg3);
    public A withNewFailedMessage(byte[] arg1,int arg2,int arg3);
    public A withNewFailedMessage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFailedMessage(String arg1);
    
/**
 * This method has been deprecated, please use method buildScheduler instead.
 * @return The buildable object.
 */
@Deprecated public ScheduleStatus getScheduler();
    public ScheduleStatus buildScheduler();
    public A withScheduler(ScheduleStatus scheduler);
    public Boolean hasScheduler();
    public A withNewScheduler(String nextRecover,String nextStart);
    public KernelChaosStatusFluent.SchedulerNested<A> withNewScheduler();
    public KernelChaosStatusFluent.SchedulerNested<A> withNewSchedulerLike(ScheduleStatus item);
    public KernelChaosStatusFluent.SchedulerNested<A> editScheduler();
    public KernelChaosStatusFluent.SchedulerNested<A> editOrNewScheduler();
    public KernelChaosStatusFluent.SchedulerNested<A> editOrNewSchedulerLike(ScheduleStatus item);
    public interface ExperimentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ExperimentStatusFluent<KernelChaosStatusFluent.ExperimentNested<N>> {

            public N and();
            public N endExperiment();    }


    public interface SchedulerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ScheduleStatusFluent<KernelChaosStatusFluent.SchedulerNested<N>> {

            public N and();
            public N endScheduler();    }


}
